<nav django-cradmin-menu class="django-cradmin-menu">
    <div class="django-cradmin-menu-mobileheader">
        <a href="#" role="button"
           class="django-cradmin-menu-mobiletoggle"
           ng-click="cradminMenuTogglePressed()"
           ng-class="{'django-cradmin-menu-mobile-toggle-button-expanded': cradminMenuDisplay}"
           aria-pressed="{{ getAriaPressed() }}">
                {{ mobileMenuHeader }}
        </a>
    </div>
    <div class="django-cradmin-menu-content"
             ng-class="{'django-cradmin-menu-content-display': cradminMenuDisplay}">
        <ul class="django-cradmin-menu-content-main">
            <li ng-repeat="urlConfig in previewConfig.urls" class="{{urlConfig.css_classes}}"
                    ng-class="{
                        'django-cradmin-menu-activeitem': $index == activeIndex
                    }">
                <a href="{{ urlConfig.url }}"
                        django-cradmin-menu-close-on-click
                        ng-click="onNavlinkClick($event, $index)">
                    {{urlConfig.label}}
                </a>
            </li>
        </ul>
        <ul class="django-cradmin-menu-content-footer">
            <li>
                <a href="{{ activeUrlConfig.url }}" target="_blank">
                    {{ activeUrlConfig.open_label }}
                </a>
            </li>
        </ul>
    </div>
</nav>
