{% extends "django_cradmin/standalone-base.django.html" %}
{% load cradmin_tags %}

{% block body %}
    {% block menu %}
        {% cradmin_render_menu %}
    {% endblock menu %}

    <div id="django_cradmin_contentwrapper">
        {% block pageheader %}
            {% if not hide_pageheader %}
                <div class="django-cradmin-page-header-outer">
                    <div class="container">
                        <div class="django-cradmin-page-header-inner">
                            {% block pageheader-inner %}{% endblock pageheader-inner %}
                        </div>
                    </div>
                </div>
            {% endif %}
        {% endblock pageheader %}

        {% block messages %}
            <div class="container">
                {% include "django_cradmin/include/messages.django.html" %}
            </div>
        {% endblock messages %}

        {% block content %}{% endblock content %}
    </div>
{% endblock body %}
