{% extends "django_cradmin/standalone-base.django.html" %}
{% comment %}
    Extends the standalone-base template to provide a layout
    suitable for pages with a single purpose such as login,
    reset password, accept invite, etc.

    ## Usage

    ```
    {% extends "django_cradmin/standalone-base.django.html" %}
    {% load crispy_forms_tags %}
    {% load i18n %}

    {% block pageheader-inner %}
        <h1>My cool page</h1>
    {% endblock pageheader-inner %}

    {% block content %}
        <div class="container">
        </div>
    {% endblock content %}
    ```
{% endcomment %}

{% block bodyclass %}
    {{ block.super }}
    django-cradmin-focusedpage-body
{% endblock bodyclass %}

{% block body %}
    <div id="django_cradmin_focusedlayout_wrapper"
         class="{% block wrapperclass %}django-cradmin-focusedpage-wrapper{% endblock %}">

        {% block messages %}
            <div id="django_cradmin_messages_standalone_wrapper">
                {% include "django_cradmin/include/messages.django.html" %}
            </div>
        {% endblock messages %}

        {% block innerwrapper_pre %}{% endblock innerwrapper_pre %}

        <div class="django-cradmin-focusedpage-wrapper-inner">
            {% block pageheader %}
                <div class="page-header">
                    {% block pageheader-inner %}{% endblock pageheader-inner %}
                </div>
            {% endblock pageheader %}

            <div id="django_cradmin_focusedlayout_content" class="django-cradmin-focusedpage-content">
                {% block content %}{% endblock content %}
            </div>
        </div>

        {% block innerwrapper_post %}{% endblock innerwrapper_post %}
    </div>
{% endblock body %}
